@@ -1,4 +1,4 @@
-# Copyright (c) 2009 Six Apart Ltd.
+# Copyright (c) 2009-2010 Six Apart Ltd.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -60,20 +60,28 @@ class HttpObject(DataObject):
     JSON API."""
 
     response_has_content = {
+        httplib.OK:                True,
+        httplib.ACCEPTED:          False,
         httplib.CREATED:           True,
+        httplib.NO_CONTENT:        False,
         httplib.MOVED_PERMANENTLY: True,
         httplib.FOUND:             True,
-        httplib.OK:                True,
         httplib.NOT_MODIFIED:      True,
-        httplib.NO_CONTENT:        False,
     }
 
     location_headers = {
+        httplib.OK:                'Content-Location',
         httplib.CREATED:           'Location',
         httplib.MOVED_PERMANENTLY: 'Location',
         httplib.FOUND:             'Location',
     }
 
+    location_header_required = {
+        httplib.CREATED:           True,
+        httplib.MOVED_PERMANENTLY: True,
+        httplib.FOUND:             True,
+    }
+
     content_types = ('application/json',)
 
     class NotFound(httplib.HTTPException):
@@ -217,7 +225,7 @@ class HttpObject(DataObject):
         except KeyError:
             pass
         else:
-            if location_header.lower() not in response:
+            if cls.location_header_required.get(response.status) and location_header.lower() not in response:
                 raise cls.BadResponse(
                     "%r header missing from %d %s response requesting %s %s"
                     % (location_header, response.status, response.reason,
@@ -264,8 +272,10 @@ class HttpObject(DataObject):
         location_header = self.location_headers.get(response.status)
         if location_header is None:
             self._location = url
-        else:
+        elif self.location_header_required.get(response.status):
             self._location = response[location_header.lower()]
+        else:
+            self._location = response.get(location_header.lower(), url)
 
         if 'etag' in response:
             self._etag = response['etag']
